@@ -315,7 +315,8 @@ class Audiences(object):
 
         if audience_queries is None:
 
-            audience_queries, raw_data = self.get_queries_from_db(au_domain=self.au_domain)
+            audience_queries, raw_data = self.get_queries_from_db(au_domain=self.au_domain,
+                                                                  allowed_audience_fields=self.allowed_audience_fields)
 
             if audience_queries is None:
                 InvalidAudienceConfiguration('No valid audiences configuration found.')
